@@ -1,4 +1,6 @@
 library(dplyr)
+# options(timeout = 120)
+options(HTTPUserAgent="Mozilla/5.0 (Linux; Android 10; K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36")
 
 set.seed(120)
 x <- fechas_elecciones %>%
